NavProperty

Enum NavProperty 

pub enum NavProperty<T: EntityTypeRef> {
    Expanded(Expanded<T>),
    Reference(Reference),
}
Navigation property variants. All navigation properties in generated code are wrapped with this type.

Variants



Expanded(Expanded<T>)

Expanded property variant (content included in the response).



Reference(Reference)

Reference variant (only @odata.id is included in the response).

Implementations

Source

impl<T: EntityTypeRef> NavProperty<T>

pub const fn new_reference(odata_id: ODataId) -> Self

Create a navigation property with a reference using the OData identifier.

pub fn to_reference(self) -> Self

Convert property to reference regardless expanded it or not.

pub fn downcast<D: EntityTypeRef>(&self) -> NavProperty<D>

Downcast to descendant type D.

Source

impl<T: EntityTypeRef> NavProperty<T>

pub fn id(&self) -> &ODataId

Extract the identifier from a navigation property.

Source

impl<T: EntityTypeRef + Sized + for<'a> Deserialize<'a> + 'static + Send + Sync> NavProperty<T>

pub async fn get<B: Bmc>(&self, bmc: &B) -> Result<Arc<T>, B::Error>

Get the property value.

Errors

If the navigation property is already expanded then no error is returned.

If the navigation is a reference then a BMC error may be returned if retrieval of the entity fails.

pub async fn filter<B: Bmc>( &self, bmc: &B, query: FilterQuery, ) -> Result<Arc<T>, B::Error>

Filter the property value using the provided query.

Errors

Returns a BMC error if filtering the entity fails.