pub struct AsyncTask {
pub id: ODataId,
pub retry_after_secs: Option<u64>,
}Expand description
Outcome of a mutating Redfish operation that can complete asynchronously.
Fields
id: ODataIdRequest completed successfully with no response body
retry_after_secs: Option<u64>The recommended number of seconds to wait before polling again