EdmDuration

Struct EdmDuration 

pub struct EdmDuration(/* private fields */);
EdmDuration represented by Edm.EdmDuration type.

This type designed to prevent data loss during deserialization and provides conversion to specific data types. If you don’t care about precision you can always use conversion to f64 seconds.

Implementations

Source

impl EdmDuration

pub fn as_f64_seconds(&self) -> f64

Convert to seconds represented as f64. Note that this function may return +Inf or -Inf if number outside of f64 range.

pub const fn as_decimal(&self) -> Decimal

Extract seconds represented be Decimal from EdmDuration.